@@ -1,6 +1,7 @@
 import sys
 import PhotoAlbum
 from Products.CMFCore import utils, DirectoryView
+from zLOG import LOG, ERROR
 
 ADD_CONTENT_PERMISSION = 'Add portal content' # disgusting isn't it ?
 
@@ -18,6 +19,14 @@ from AccessControl import allow_class
 from Products.CMFPlone.PloneBatch import Batch
 allow_class(Batch)
 
+# test for CMFPhoto
+try:
+    import Products.CMFPhoto
+except ImportError, err:
+    LOG('CMFPhotoAlbum', ERROR, 'CMFPhoto not installed',
+    'Please install CMFPhoto from http://sourceforge.net/projects/collective/')
+
+
 def initialize(registrar):
     utils.initializeBasesPhase2(z_bases, registrar)
     utils.ContentInit(
